@@ -8,14 +8,14 @@ App::CLI::Extension::Component::Config - for App::CLI::Extension config module
 
 =head1 VERSION
 
-1.1
+1.2
 
 =cut
 
 use strict;
 use base qw(Class::Data::Accessor);
 
-our $VERSION  = '1.1';
+our $VERSION  = '1.2';
 
 __PACKAGE__->mk_classaccessor( _config => {} );
 
@@ -42,7 +42,7 @@ __END__
 
 =head1 SEE ALSO
 
-L<App::CLI::Extension>
+L<App::CLI::Extension> L<Class::Data::Accessor>
 
 =head1 AUTHOR
 
