@@ -8,7 +8,7 @@ App::CLI::Extension::Component::OriginalArgv - for App::CLI::Extension original
 
 =head1 VERSION
 
-1.1
+1.2
 
 =cut
 
@@ -17,7 +17,7 @@ use base qw(Class::Data::Accessor);
 use FindBin qw($Bin $Script);
 use File::Spec;
 
-our $VERSION  = '1.1';
+our $VERSION  = '1.2';
 
 __PACKAGE__->mk_classaccessor("_orig_argv");
 __PACKAGE__->mk_classaccessor("argv0"      => $Script);
@@ -54,7 +54,7 @@ __END__
 
 =head1 SEE ALSO
 
-L<App::CLI::Extension>
+L<App::CLI::Extension> L<Class::Data::Accessor>
 
 =head1 AUTHOR
 
