@@ -5,8 +5,9 @@ use strict;
 sub fail {
 
     my($self, @argv) = @_;
-    $main::RESULT = $self->error; 
-#    $self->maybe::next::method(@argv);
+    $main::RESULT = $self->errstr; 
+	$self->exit_value(1);
+    $self->maybe::next::method(@argv);
 }
 
 1;
